@@ -197,11 +197,11 @@ class file_options:
                                  'mesh_complete_folder': None,
                                  'mesh_surfaces_folder': None,
                                  'postprocessing_folder':None}
-        if not os.path.isdir(outdir+'/DATA'):
+        if not os.path.isdir(outdir+'/CCO_DATA'):
             directory_constructor['create_main_folder'] = True
         else:
             directory_constructor['create_main_folder'] = False
-        directory_constructor['main_folder'] = outdir+'/DATA'
+        directory_constructor['main_folder'] = outdir+'/CCO_DATA'
         number = len(glob.glob(directory_constructor['main_folder']+'/CCO_*'))
         directory_constructor['data_folder'] = directory_constructor['main_folder']+'/simulation_data{}'.format(number)
         directory_constructor['mesh_complete_folder'] = directory_constructor['data_folder']+'/mesh-complete'
